# df

display free disk space in human-readable format

    df -h


display human-readable free disk space of file system where foo.txt is stored

    df -h foo.txt


display free disk space of all file systems

    df -a


display free disk space of locally mounted file systems

    df -l


display human-readable free disk space of nfs-type file systems

    df -hT nfs



# Basic Usage

Show the free disk space of a file system in human-readable (`-h`) format:

    df -h


